@@ -1,16 +1,17 @@
 require 'spec_helper'
 
 describe 'cinder::client' do
-
   let :params do
     {}
   end
 
   let :default_params do
-    { :package_ensure   => 'present' }
+    {
+      :package_ensure => 'present'
+    }
   end
 
-  shared_examples_for 'cinder client' do
+  shared_examples 'cinder client' do
     let :p do
       default_params.merge(params)
     end
@@ -19,7 +20,7 @@ describe 'cinder::client' do
 
     it 'installs cinder client package' do
       is_expected.to contain_package('python-cinderclient').with(
-        :name   => 'python-cinderclient',
+        :name   => platform_params[:client_package_name],
         :ensure => p[:package_ensure],
         :tag    => ['openstack', 'cinder-support-package'],
       )
@@ -42,7 +43,20 @@ describe 'cinder::client' do
         facts.merge(OSDefaults.get_facts({:os_workers => 8}))
       end
 
-      it_configures 'cinder client'
+      let(:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          if facts[:os_package_type] == 'debian'
+            { :client_package_name => 'python3-cinderclient' }
+          else
+            { :client_package_name => 'python-cinderclient' }
+          end
+        when 'RedHat'
+          { :client_package_name => 'python-cinderclient' }
+        end
+      end
+
+      it_behaves_like 'cinder client'
     end
   end
 end
